/* vc_cpp */
/*
 * Problem  :   POINTS
 * Contest  :   UOI-2008 (LVIV)
 * Type     :   Solution
 * Date     :   Kvitnya 9, 2008
 * Version  :   1.0
 * Author   :   Taras Galkovsky
 * Language :   C++
 * Compiler :   MS Visual C++
 * Algorithm:   O (N log N) sorting
 */
#include <vector>
#include <algorithm>
#define _USE_MATH_DEFINES
#include <math.h>
#include <assert.h>

using namespace std;

#define EPS 1e-10
FILE * fin = fopen("points.dat", "r");
FILE * fout = fopen("points.sol", "w");

struct point
{
	int x, y;
};

struct pointA
{
	int x, y;
	double a;
	int id;

	pointA () {}

	pointA (point p, double A, int Id)
	{
		x = p.x;
		y = p.y;
		a = A;
		id = Id;
	}
};

bool cmp1 (pointA a, pointA b)
{
	return a.a < b.a;
}

inline double dist(point A, point B) {
	double dx = (double)A.x - (double)B.x;
	double dy = (double)A.y - (double)B.y;
	return sqrt(dx*dx + dy*dy);
}

inline double angle (point A, point O, point B)
{
	A.x -= O.x;
	A.y -= O.y;
	B.x -= O.x;
	B.y -= O.y;

	double a = atan2((double)(- A.x * B.y + A.y * B.x), (double)(A.x * B.x + A.y * B.y));
	//if (a < 0)		a += 2 * M_PI;
	if (a < 0)
		a = -a - M_PI;
	return a;
}

int n;
point A, B, O;
vector<pointA> pA, pB;
vector<bool> mask;

int main ()
{
	int i, j, ans, always;
	ans = always = 0;
	fscanf(fin, "%d", &n);
	fscanf(fin, "%d%d%d%d", &A.x, &A.y, &B.x, &B.y);

	mask.resize(n, 0);

	assert(A.x != B.x || A.y != B.y);

	O.x = A.x - (B.x - A.x);
	O.y = A.y - (B.y - A.y);

	point p;
	for (i = 0; i < n; ++i) {
		fscanf(fin, "%d%d", &p.x, &p.y);
		if (p.x == A.x && p.y == A.y ||
			p.x == B.x && p.y == B.y)
			always ++;
		else {
			double a = angle(O, A, p);
			if (fabs(a) < EPS || fabs(fabs(a) - M_PI) < EPS) {
				if (dist(A, B) + 1e-5 > dist(p, A) + dist(p, B))
					always ++;
				else
					ans ++;
			}
			else {
				pA.push_back(pointA(p, angle(O, A, p), i));
				pB.push_back(pointA(p, angle(O, B, p), i));
			}
		}
	}

	ans += always;

	n = pA.size();

	sort(pA.begin(), pA.end(), &cmp1);
	sort(pB.begin(), pB.end(), &cmp1);

	vector<pointA> incl, excl;
	for (i = 0; i < pA.size(); ++i)
		if (pA[i].a > 0)
			excl.push_back(pA[i]);
		else
			incl.push_back(pA[i]);

	for (i = 0; i < pB.size(); ++i)
		if (pB[i].a > 0)
			incl.push_back(pB[i]);
		else
			excl.push_back(pB[i]);

	n = incl.size();

	assert(incl.size() == excl.size());

	for (i = 0; i < n; ++i) {
		if (incl[i].a < 0)
			incl[i].a *= -1.;
		if (excl[i].a < 0)
			excl[i].a *= -1.;
	}
	sort(incl.begin(), incl.end(), &cmp1);
	sort(excl.begin(), excl.end(), &cmp1);

	int cur = always;
	for (i = j = 0; i < n || j < n; )
	{
		assert(cur >= 0);
		if (i < n && j < n) {
			if (incl[i].a < excl[j].a+EPS) {
				cur ++;
				mask[incl[i].id] = true;
				i ++;
			}
			else {
				cur --;
				mask[excl[j].id] = false;
				j ++;
			}
		}
		else if (i < n) {
			cur++;
			mask[incl[i].id] = true;
			i++;
		}
		else if (j < n) {
			cur --;
			mask[excl[j].id] = false;
			j++;
		}

		ans = max(ans, cur);
	}

	fprintf(fout, "%d\n", ans);

	fclose(fin);
	fclose(fout);
/*
	fout = fopen("points.1.rep", "w");
	fprintf(fout, "%0.12f\n", EPS);
	for (i = 0; i < incl.size(); ++i)
		fprintf(fout, "%0.12f\n", incl[i].a);
	fclose(fout);

	fout = fopen("points.2.rep", "w");
	fprintf(fout, "%0.12f\n", EPS);
	for (i = 0; i < excl.size(); ++i)
		fprintf(fout, "%0.12f\n", excl[i].a);
	fclose(fout);
*/
	return 0;
};