/* vc_cpp */
#include <vector>
#include <algorithm>
#define _USE_MATH_DEFINES
#include <math.h>
#include <assert.h>

using namespace std;

#define EPS 1e-9

FILE * fin = fopen("points.dat", "r");
FILE * fout = fopen("points.sol", "w");

struct point
{
	int x, y;
};

inline double vprod(point A, point B, point C)
{
	return ((double)A.x - (double)B.x) * ((double)C.y - (double)B.y) - ((double)A.y - (double)B.y) * ((double)C.x - (double)B.x);
}

inline double angle (point A, point O, point B)
{
	A.x -= O.x;
	A.y -= O.y;
	B.x -= O.x;
	B.y -= O.y;

	double a = atan2((double)(- A.x * B.y + A.y * B.x), (double)(A.x * B.x + A.y * B.y));
	//if (a < 0)		a += 2 * M_PI;
	if (a < 0)
		a = -a - M_PI;
	return a;
}

int n;
point A, B;
vector<point> p;

int calc (point A, point A_, point B, point B_, bool show=false)
{
	int ans = 0;
	for (int i = 0; i < n; ++i)
	{
		double p1 = vprod(p[i], A, A_);
		double p2 = vprod(p[i], B, B_);

		if (fabs(p1) < EPS || fabs(p2) < EPS || 
			p1 * p2 < 0)
		{
			ans++;
			if (show)
				printf("%d\n", i);
		}
	}
	return ans;
}

int main ()
{
	int i, ans;
	point O;
	point A_, B_;
	ans = 0;
	fscanf(fin, "%d", &n);
	fscanf(fin, "%d%d%d%d", &A.x, &A.y, &B.x, &B.y);

	assert(A.x != B.x || A.y != B.y);

	O.x = A.x - (B.x - A.x);
	O.y = A.y - (B.y - A.y);

	p.resize(n);
	for (i = 0; i < n; ++i)
		fscanf(fin, "%d%d", &p[i].x, &p[i].y);

	for (i = 0; i < n; ++i)
		if (p[i].x == A.x && p[i].y == A.y ||
			p[i].x == B.x && p[i].y == B.y)
			ans ++;

	for (i = 0; i < n; ++i)
	{
		A_.x = p[i].x;
		A_.y = p[i].y;

		if ((A_.x != A.x || A_.y != A.y) &&
			(A_.x != B.x || A_.y != B.y))
		{
			B_.x = B.x + (A_.x - A.x);
			B_.y = B.y + (A_.y - A.y);

			int t = calc(A, A_, B, B_);
			
			if (ans < t)
			{
				ans = t;
			//	printf("%d %d %d A\n", p[i].x, p[i].y, ans);
			}
		}

		B_.x = p[i].x;
		B_.y = p[i].y;

		if ((B_.x != A.x || B_.y != A.y) &&
			(B_.x != B.x || B_.y != B.y))
		{
			A_.x = A.x + (B_.x - B.x);
			A_.y = A.y + (B_.y - B.y);

			int t = max(ans, calc(A, A_, B, B_));
			if (ans < t)
			{
				ans = t;
			//	printf("%d %d %d B\n", p[i].x, p[i].y, ans);

				/*
				if (ans == 150) {
					calc(A, A_, B, B_, true);
				}
				*/
			}
		}
	}

	fprintf(fout, "%d\n", ans);

	fclose(fin);
	fclose(fout);
	return 0;
};